==> hutool-2.9.2-sources.jar: com/xiaoleilu/hutool/CronUtil.java <==
package com.xiaoleilu.hutool;

import it.sauronsoftware.cron4j.Scheduler;

import java.util.Map.Entry;

import org.slf4j.Logger;

import com.xiaoleilu.hutool.exceptions.UtilException;

/**
 * 定时任务工具类
 * @author xiaoleilu
 *
 */
public class CronUtil {
	private static Logger log = Log.get();
	
	/** Crontab配置文件 */
	public final static String CRONTAB_CONFIG_PATH = "config/cron4j.setting";
	
	private final static Scheduler scheduler = new Scheduler();
	private static Setting crontab;
	
	/**
	 * 自定义定时任务配置文件
	 * @param cronSetting 定时任务配置文件 
	 */
	public static void setCronSetting(Setting cronSetting) {
		crontab = cronSetting;
	}
	
	/**
	 * 自定义定时任务配置文件路径
	 * @param cronSettingPath 定时任务配置文件路径（相对绝对都可）
	 */
	public static void setCronSetting(String cronSettingPath) {
		crontab = new Setting(cronSettingPath, Setting.DEFAULT_CHARSET, false);
	}
	
	/**
	 * 加入定时任务
	 * @param schedulingPattern 定时任务执行时间的crontab表达式
	 * @param task 任务
	 */
	public static void schedule(String schedulingPattern, Runnable task) {
		scheduler.schedule(schedulingPattern, task);
	}
	
	/**
	 * 批量加入配置文件中的定时任务
	 * @param cronSetting 定时任务设置文件
	 */
	public static void schedule(Setting cronSetting) {
		for (Entry<String, String> entry : cronSetting.entrySet()) {
			final String jobClass = entry.getKey();
			final String pattern = entry.getValue();
			try {
				final Runnable job = ClassUtil.newInstance(jobClass);
				schedule(pattern, job);
				log.info("Schedule [{} {}] added.", pattern, jobClass);
			} catch (Exception e) {
				Log.error(log, e, "Schedule [%s %s] add error!", pattern, jobClass);
			}
		}
	}
	
	/**
	 * 开始
	 */
	synchronized public static void start() {
		if(null == crontab) {
			setCronSetting(CRONTAB_CONFIG_PATH);
		}
		if(scheduler.isStarted()) {
			throw new UtilException("Scheduler has been started, please stop it first!");
		}
		
		schedule(crontab);
		scheduler.start();
	}
	
	/**
	 * 停止
	 */
	synchronized public static void stop() {
		scheduler.stop();
	}
	
}

==> hutool-2.12.2-sources.jar: com/xiaoleilu/hutool/CronUtil.java <==
package com.xiaoleilu.hutool;

import java.util.Map.Entry;

import org.slf4j.Logger;

import com.xiaoleilu.hutool.exceptions.UtilException;

import it.sauronsoftware.cron4j.Scheduler;
import it.sauronsoftware.cron4j.Task;

/**
 * 定时任务工具类
 * @author xiaoleilu
 *
 */
public class CronUtil {
	private static Logger log = Log.get();
	
	/** Crontab配置文件 */
	public final static String CRONTAB_CONFIG_PATH = "config/cron4j.setting";
	
	private final static Scheduler scheduler = new Scheduler();
	private static Setting crontabSetting;
	
	/**
	 * 自定义定时任务配置文件
	 * @param cronSetting 定时任务配置文件 
	 */
	public static void setCronSetting(Setting cronSetting) {
		crontabSetting = cronSetting;
	}
	
	/**
	 * 自定义定时任务配置文件路径
	 * @param cronSettingPath 定时任务配置文件路径（相对绝对都可）
	 */
	public static void setCronSetting(String cronSettingPath) {
		crontabSetting = new Setting(cronSettingPath, Setting.DEFAULT_CHARSET, false);
	}
	
	/**
	 * 加入定时任务
	 * @param schedulingPattern 定时任务执行时间的crontab表达式
	 * @param task 任务
	 * @return 定时任务ID
	 */
	public static String schedule(String schedulingPattern, Task task) {
		return scheduler.schedule(schedulingPattern, task);
	}
	
	/**
	 * 加入定时任务
	 * @param schedulingPattern 定时任务执行时间的crontab表达式
	 * @param task 任务
	 * @return 定时任务ID
	 */
	public static String schedule(String schedulingPattern, Runnable task) {
		return scheduler.schedule(schedulingPattern, task);
	}
	
	/**
	 * 批量加入配置文件中的定时任务
	 * @param cronSetting 定时任务设置文件
	 */
	public static void schedule(Setting cronSetting) {
		for (Entry<String, String> entry : cronSetting.entrySet()) {
			final String jobClass = entry.getKey();
			final String pattern = entry.getValue();
			try {
				final Runnable job = ClassUtil.newInstance(jobClass);
				schedule(pattern, job);
				log.info("Schedule [{} {}] added.", pattern, jobClass);
			} catch (Exception e) {
				Log.error(log, e, "Schedule [%s %s] add error!", pattern, jobClass);
			}
		}
	}
	
	/**
	 * 移除任务
	 * @param schedulerId 任务ID
	 */
	public void remove(String schedulerId){
		scheduler.deschedule(schedulerId);
	}
	
	/**
	 * @return 获得cron4j的Scheduler对象
	 */
	public Scheduler getScheduler(){
		return scheduler;
	}
	
	/**
	 * 开始
	 */
	synchronized public static void start() {
		if(null == crontabSetting) {
			setCronSetting(CRONTAB_CONFIG_PATH);
		}
		if(scheduler.isStarted()) {
			throw new UtilException("Scheduler has been started, please stop it first!");
		}
		
		schedule(crontabSetting);
		scheduler.start();
	}
	
	/**
	 * 重新启动定时任务<br>
	 * 重新启动定时任务会清除动态加载的任务
	 */
	synchronized public static void restart(){
		if(null != crontabSetting){
			crontabSetting.reload();
		}
		if(scheduler.isStarted()){
			scheduler.stop();
		}
		scheduler.start();
	}
	
	/**
	 * 停止
	 */
	synchronized public static void stop() {
		scheduler.stop();
	}
	
}
